==> nextcloud-php72-19.0.3.txz: usr/local/www/nextcloud/apps-pkg/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "File could not be found" : "Il file non può essere trovato",
    "Move or copy" : "Sposta o copia",
    "Download" : "Scarica",
    "Delete" : "Elimina",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Favorites" : "Preferiti",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
    "Upload cancelled." : "Caricamento annullato.",
    "Processing files …" : "Elaborazione file in corso…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
    "Uploading …" : "Caricamento in corso...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
    "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
    "Actions" : "Azioni",
    "Rename" : "Rinomina",
    "Copy" : "Copia",
    "Choose target folder" : "Scegli la cartella di destinazione",
    "Open" : "Apri",
    "Delete file" : "Elimina file",
    "Delete folder" : "Elimina cartella",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Leave this share" : "Abbandona questa condivisione",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Files" : "File",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "copy" : "copia",
    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Could not fetch file details \"{file}\"" : "Impossibile recuperare i dettagli del file \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti"],
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "Select file range" : "Seleziona intervallo di file",
    "{used} of {quota} used" : "{used} di {quota} utilizzati",
    "{used} used" : "{used} utilizzati",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "This group folder is full, files can not be updated or synced anymore!" : "Questa cartella di gruppo è piena, i file non possono più essere aggiornati o sincronizzati!",
    "This external storage is full, files can not be updated or synced anymore!" : "Questa archiviazione esterna è piena, i file non possono più essere aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%).",
    "This group folder is almost full ({usedSpacePercent}%)." : "Questa cartella di gruppo è quasi piena ({usedSpacePercent}%).",
    "This external storage is almost full ({usedSpacePercent}%)." : "Questa archiviazione esterna è quasi piena ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "View in folder" : "Visualizza nella cartella",
    "Copied!" : "Copiato!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "You can only favorite a single file or folder at a time" : "Puoi aggiungere ai preferiti un singolo file o cartella alla volta",
    "New folder" : "Nuova cartella",
    "Upload file" : "Carica file",
    "Recent" : "Recenti",
    "Not favorited" : "Non preferito",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "\"remote user\"" : "\"utente remoto\"",
    "You created {file}" : "Hai creato {file}",
    "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creato un file cifrato in {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "You changed an encrypted file in {file}" : "Hai cambiato un file cifrato in {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha cambiato un file cifrato in {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "You deleted an encrypted file in {file}" : "Hai eliminato un file cifrato in {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha eliminato un file cifrato in {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user} ha ripristinato {file}",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un file preferito o una cartella è stato <strong>modificato</strong>",
    "All files" : "Tutti i file",
    "Unlimited" : "Illimitata",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "Accept" : "Accetta",
    "Reject" : "Rifiuta",
    "Incoming ownership transfer from {user}" : "Trasferimento di proprietà in ingresso da {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vuoi accettare {path}?\n\nNota: il processo di trasferimento dopo l'accettazione potrebbe richiedere fino a un'ora.",
    "Ownership transfer failed" : "Trasferimento di proprietà non riuscito",
    "Your ownership transfer of {path} to {user} failed." : "Il tuo trasferimento di proprietà di {path} a {user} non è riuscito.",
    "The ownership transfer of {path} from {user} failed." : "Il trasferimento di proprietà di {path} da {user} non è riuscito.",
    "Ownership transfer done" : "Trasferimento di proprietà completato",
    "Your ownership transfer of {path} to {user} has completed." : "Il tuo trasferimento di proprietà di {path} a {user} è completato.",
    "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
    "in %s" : "in %s",
    "File Management" : "Gestione dei file",
    "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
    "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Change" : "Modifica",
    "New owner" : "Nuovo proprietario",
    "Search users" : "Cerca utenti",
    "Choose a file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Transfer" : "Trasferisci",
    "Transfer {path} to {userid}" : "Trasferisci {path} a {userid}",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
    "Cannot transfer ownership of a file or folder you don't own" : "Impossibile trasferire la proprietà di un file o di una cartella di altri",
    "Tags" : "Etichette",
    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
    "%s used" : "%s utilizzato",
    "%s%% of %s used" : "%s%% di %s utilizzati",
    "%1$s of %2$s used" : "%1$s di %2$s utilizzati",
    "Settings" : "Impostazioni",
    "Show hidden files" : "Mostra i file nascosti",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
    "Toggle grid view" : "Commuta la vista a griglia",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Deleted files" : "File eliminati",
    "Shares" : "Condivisioni",
    "Shared with others" : "Condivisi con altri",
    "Shared with you" : "Condivisi con te",
    "Shared by link" : "Condivisi tramite collegamento",
    "Deleted shares" : "Condivisioni eliminate",
    "Pending shares" : "Condivisioni in corso",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "Unshare" : "Rimuovi condivisione",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un file o una cartella è stato <strong>modificato</strong> o <strong>rinominato</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">accedere ai tuoi file con WebDAV</a>",
    "Cannot transfter ownership of a file or folder you don't own" : " Impossibile trasferire la proprietà di un file o di una cartella di altri",
    "This group folder is almost full ({usedSpacePercent}%)" : "Questa cartella di gruppo è quasi piena ({usedSpacePercent}%)",
    "This external storage is almost full ({usedSpacePercent}%)" : "Questa archiviazione esterna è quasi piena ({usedSpacePercent}%)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-php74-20.0.7.txz: usr/local/www/nextcloud/apps-pkg/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "File could not be found" : "Il file non può essere trovato",
    "Move or copy" : "Sposta o copia",
    "Download" : "Scarica",
    "Delete" : "Elimina",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Favorites" : "Preferiti",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "This will stop your current uploads." : "Questo fermerà i caricamenti attuali.",
    "Upload cancelled." : "Caricamento annullato.",
    "Processing files …" : "Elaborazione file in corso…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "An unknown error has occurred" : "Si è verificato un errore sconosciuto",
    "Uploading …" : "Caricamento in corso...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Il caricamento di tale elemento non è supportato",
    "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
    "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
    "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
    "Actions" : "Azioni",
    "Rename" : "Rinomina",
    "Copy" : "Copia",
    "Choose target folder" : "Scegli la cartella di destinazione",
    "Open" : "Apri",
    "Delete file" : "Elimina file",
    "Delete folder" : "Elimina cartella",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Leave this share" : "Abbandona questa condivisione",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Files" : "File",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "copy" : "copia",
    "Could not copy \"{file}\", target exists" : "Impossibile copiare \"{file}\", la destinazione esiste già",
    "Could not copy \"{file}\"" : "Impossibile copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "Copiato {origin} in {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiati {origin} e {nbfiles} altri file in {destination}",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Could not fetch file details \"{file}\"" : "Impossibile recuperare i dettagli del file \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti"],
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "Select file range" : "Seleziona intervallo di file",
    "{used} of {quota} used" : "{used} di {quota} utilizzati",
    "{used} used" : "{used} utilizzati",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"/\" is not allowed inside a file name." : "\"/\" non è consentito nel nome di un file.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "La cartella di gruppo \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "L'archiviazione esterna \"{mountPoint}\" è piena, i file non possono più essere aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "View in folder" : "Visualizza nella cartella",
    "Copied!" : "Copiato!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "You can only favorite a single file or folder at a time" : "Puoi aggiungere ai preferiti un singolo file o cartella alla volta",
    "New folder" : "Nuova cartella",
    "Upload file" : "Carica file",
    "Recent" : "Recenti",
    "Not favorited" : "Non preferito",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "\"remote user\"" : "\"utente remoto\"",
    "You created {file}" : "Hai creato {file}",
    "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creato un file cifrato in {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "You changed an encrypted file in {file}" : "Hai cambiato un file cifrato in {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha cambiato un file cifrato in {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "You deleted an encrypted file in {file}" : "Hai eliminato un file cifrato in {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha eliminato un file cifrato in {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user} ha ripristinato {file}",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un file preferito o una cartella è stato <strong>modificato</strong>",
    "All files" : "Tutti i file",
    "Unlimited" : "Illimitata",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "Accept" : "Accetta",
    "Reject" : "Rifiuta",
    "Incoming ownership transfer from {user}" : "Trasferimento di proprietà in ingresso da {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vuoi accettare {path}?\n\nNota: il processo di trasferimento dopo l'accettazione potrebbe richiedere fino a un'ora.",
    "Ownership transfer failed" : "Trasferimento di proprietà non riuscito",
    "Your ownership transfer of {path} to {user} failed." : "Il tuo trasferimento di proprietà di {path} a {user} non è riuscito.",
    "The ownership transfer of {path} from {user} failed." : "Il trasferimento di proprietà di {path} da {user} non è riuscito.",
    "Ownership transfer done" : "Trasferimento di proprietà completato",
    "Your ownership transfer of {path} to {user} has completed." : "Il tuo trasferimento di proprietà di {path} a {user} è completato.",
    "The ownership transfer of {path} from {user} has completed." : "Il trasferimento di proprietà di {path} da {user} è completato.",
    "in %s" : "in %s",
    "File Management" : "Gestione dei file",
    "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
    "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Change" : "Modifica",
    "New owner" : "Nuovo proprietario",
    "Search users" : "Cerca utenti",
    "Choose a file or folder to transfer" : "Scegli file o cartella da trasferire",
    "Transfer" : "Trasferisci",
    "Transfer {path} to {userid}" : "Trasferisci {path} a {userid}",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
    "Cannot transfer ownership of a file or folder you don't own" : "Impossibile trasferire la proprietà di un file o di una cartella di altri",
    "Tags" : "Etichette",
    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
    "Pick a template for {name}" : "Scegli un modello per {name}",
    "Cancel" : "Annulla",
    "Create" : "Crea",
    "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
    "Creating file" : "Creazione del file",
    "Blank" : "Vuoto",
    "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
    "Set up templates folder" : "Configura la cartella dei modelli",
    "Templates" : "Modelli",
    "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
    "%s used" : "%s utilizzato",
    "%s%% of %s used" : "%s%% di %s utilizzati",
    "%1$s of %2$s used" : "%1$s di %2$s utilizzati",
    "Settings" : "Impostazioni",
    "Show hidden files" : "Mostra i file nascosti",
    "Crop image previews" : "Ritaglia le anteprime delle immagini",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
    "Toggle grid view" : "Commuta la vista a griglia",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Deleted files" : "File eliminati",
    "Shares" : "Condivisioni",
    "Shared with others" : "Condivisi con altri",
    "Shared with you" : "Condivisi con te",
    "Shared by link" : "Condivisi tramite collegamento",
    "Deleted shares" : "Condivisioni eliminate",
    "Pending shares" : "Condivisioni in corso",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "Unshare" : "Rimuovi condivisione",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "La cartella di gruppo \"{mountPoint}\" è quasi piena ({usedSpacePercent}%)",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un file o una cartella è stato <strong>modificato</strong> o <strong>rinominato</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>"
},
"nplurals=2; plural=(n != 1);");
